//-----------------------------------------------------------------------
//	Java Indexed Serialization Package
//  ----------------------------------
//  DuplicateKey.java
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 1996-2003 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any legal purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

package com.coyotegulch.jisp;

/**
 * A <code>ObjectIndex</code> throws a <code>DuplicateKey</code> when a key being added to the
 * index is identical to a key already stored there. Each concrete index class
 * determines the circumstances under which this exception is thrown. For example, 
 * a <code>BTreeIndex</code> will throw <code>DuplicateKey</code>
 * when a call to the <code>insertKey</code> method finds an existing key that
 * matches the insertion key; however, the <code>BTreeIndex.writeKey</code> method
 * does not throw an exception for a duplicate key, instead replacing the record
 * position associated with the extant key.
 * <p>
 * @author	Scott Robert Ladd
 * @see		com.coyotegulch.jisp.ObjectIndex
 * @see		com.coyotegulch.jisp.BTreeIndex
 */
public class DuplicateKey extends DatabaseException
{
    /**
     * Constructs a new <code>DuplicateKey</code> with null as its error message string.
     */
    public DuplicateKey()
    {
        super();
    }

    /**
     * Constructs a new <code>DuplicateKey</code> with <code>message</code> as its error message string.
     *
     * @param   message   Error message string.
     */
    public DuplicateKey(String message)
    {
        super(message);
    }
}
