//-----------------------------------------------------------------------
//  Java Indexed Serialization Package
//  ----------------------------------
//  IndexIterator.java
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 1996-2003 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any legal purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

package com.coyotegulch.jisp;

import java.io.IOException;

/**
 * <code>IndexIterator</code> defines an object that references a specific object relative to other 
 * objects in an <code>ObjectIndex</code>.
 * <p>
 * @author  Scott Robert Ladd
 * @see     com.coyotegulch.jisp.ObjectIndex
 * @see     com.coyotegulch.jisp.BTreeIndex
 * @see     com.coyotegulch.jisp.BTreeIterator
 * @see     com.coyotegulch.jisp.IndexedObjectDatabase
 */
public interface IndexIterator
{
    /**
     * Returns the record <code>Object</code> currently referenced by this iterator.
     *
     * @return  a <code>long</code> pointer (usually a file position) associated with this index
     *          entry; returns -1 if the iterator is invalid or the record was not found
     */
    long getRecPtr() throws IOException;
    
    /**
     * Returns the key <code>Object</code> currently referenced by this iterator.
     *
     * @return  the key <code>Object</code> currently referenced by this iterator; returns
     *          <code>null</code> if the iterator is invalid or the record was not found
     */
    Object getKey() throws IOException;
    
    /**
     * Moves this iterator to the next record in sequence. 
     *
     * @return <code>true</code> if the operation was successful; <code>false</code> otherwise
     */
    boolean moveNext() throws IOException, ClassNotFoundException;
    
    /**
     * Moves this iterator to the previous record in sequence. 
     *
     * @return <code>true</code> if the operation was successful; <code>false</code> otherwise.
     */
    boolean movePrevious() throws IOException, ClassNotFoundException;
    
    /**
     * Moves this iterator to the first record in sequence.
     *
     * @return <code>true</code> if the operation was successful; <code>false</code> otherwise.
     */
    boolean moveFirst() throws IOException, ClassNotFoundException;
    
    /**
     * Moves this iterator to the last record in sequence.
     *
     * @return <code>true</code> if the operation was successful; <code>false</code> otherwise.
     */
    boolean moveLast() throws IOException, ClassNotFoundException;
    
    /**
     * Moves this iterator to the record associated with the given <code>key</code>.
     *
     * @param   key                     key identifier to find
     * @return <code>true</code> if the operation was successful; <code>false</code> otherwise.
     */
    boolean moveTo(KeyObject key) throws IOException, ClassNotFoundException;
    
    /**
     * Moves this iterator to the record associated with the given <code>key</code>.
     *
     * @param   key                     key identifier to find
     * @return <code>true</code> if the operation was successful; <code>false</code> otherwise.
     */
    boolean moveTo(KeyObject key, boolean acceptNext) throws IOException, ClassNotFoundException;
    
    /**
     * Checks to see if this iterator is valid.
     *
     * @return <code>true</code> if the iterator is valid; <code>false</code> if it is invalid.
     */
    boolean isValid();
}
