//-----------------------------------------------------------------------
//  Java Indexed Serialization Package
//  ----------------------------------
//  BTreeIndex.java
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 1996-2003 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any legal purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

package com.coyotegulch.jisp;


/**
 * Defines common, global objects for the entire Jisp package.
 *
 * @author  Scott Robert Ladd
 */
public class Jisp
{
    /**
    *   Version number string.
    */
    public static final String VERSION = "2.5.1";
    
    /**
    *   "Scott's Very Free License", the license governing the distribution and use of Jisp.
    */
    public static final String LICENSE =
            "\nJisp " + VERSION + "\n" +
            "\nCopyright 1996-2003 Scott Robert Ladd." +
            "\nAll rights reserved, except as noted herein.\n" +
            "\nSCOTT'S VERY FREE LICENSE\n" +
            "This computer program is supplied \"AS IS\". Scott Robert Ladd\n" +
            "(hereinafter referred to as \"Author\") disclaims all warranties,\n" +
            "expressed or implied, including, without limitation, the warranties\n" +
            "of merchantability and of fitness for any purpose. The Author\n" +
            "assumes no liability for direct, indirect incidental, special,\n" +
            "exemplary, or consequential damages, which may result from the use\n" +
            "of this free product, even if advised of the possibility of such\n" +
            "damage.\n\n" +
            "The Author hereby grants anyone permission to use and distribute\n" +
            "this program, for any legal purpose, without fee, subject to the\n" +
            "following restrictions:\n\n" +
            "    1) The origin of this program must not be misrepresented.\n\n" +
            "    2) Altered versions must be plainly marked as such and\n" +
            "         must not be misrepresented.\n\n" +
            "    3) This copyright notice may not be removed or altered\n" +
            "         from any distribution of this program.\n\n" +
            "The Author specifically permits (without fee) and encourages the\n" +
            "use of this program for entertainment, education, or decoration. If\n" +
            "you use this program or its source code in another product,\n" +
            "acknowledgment is not required but would be appreciated. The author's\n" +
            "contact information is available at:\n\n" +
            "    scott@coyotegulch.com\n" +
            "    http://www.coyotegulch.com.\n\n" +
            "Acknowledgement: This license is based on the wonderful license that\n" +
            "accompanies libpng.\n";
            
    private static final String HEADER =
            "\nJisp - The Java Indexed Serialization Package\n" +
            "---------------------------------------------\n" +
            "The Jisp package (com.coyotegulch.jisp) uses B-Tree and hash\n" +
            "indexes for keyed access to variable-length serialized objects\n" +
            "stored in files. Jisp is \"Pure Java\", developed with Sun's\n" +
            "Java 2 for portability, and tested with JDKs 1.3.1 and 1.4.0.\n" +
            "Build your application around Jisp, and you have a database that\n" +
            "is 100% portable between platforms; the source code is in your\n" +
            "hand, and you control precisely how your data is related and\n" +
            "accessed. This is terrific for standalone applications, where\n" +
            "an enterprise-class database is not a reasonable option.\n\n" +
            "Jisp is a tool for people who are comfortable defining their\n" +
            "database relationships \"on the metal\", as opposed to using a GUI\n" +
            "interface to \"draw\" a database. I use enterprise-class databases,\n" +
            "and don't for a moment believe I've replaced them with Jisp -- what\n" +
            "I have done is create a tool for applications that don't lend\n" +
            "themselves to \"heavy\" solutions like Oracle, SQL Server or Access.\n" +
            "I've used Jisp in vertical-market databases and peer-to-peer\n" +
            "systems; other people have used Jisp in projects ranging from\n" +
            "WAP applications to parts of the Apache project.\n" +
            "---------------------------------------------\n";
            
    static final boolean TRACE = true;

    // external class loader supplied by setClassLoader    
    private static ClassLoader m_classLoader;

    /**
     *  Set an external class loader for use by the Jisp object input and output streams.
     *
     *  @param  loader  a class loader, or <code>null</code> to revert to the default.
     */
    public static void setClassLoader(ClassLoader loader) 
    {
        m_classLoader = loader;
    }

    /**
     *  Get the current class loader. If a <code>ClassLoader</code> has not been set via the
     *  <code>setClassLoader</code>, or the <code>ClassLoader</code> is set to <code>null</code>,
     *  this function returns the the ClassLoader for the current thread context.
     *
     *  @return     The current class loader, or the thread context class loader.
     */
    public static ClassLoader getClassLoader()
    {
        if (m_classLoader == null)
            return Thread.currentThread().getContextClassLoader();
        else
            return m_classLoader;
    }
    
    /**
     *  The main function, run from the jisp JAR file to display version number and license.
     *
     *  @param  args    Program arguments (ignored)
     */
     public static void main(String [] args)
     {
        System.err.println(HEADER + LICENSE);
     }
}
