//-----------------------------------------------------------------------
//	Java m_indexed Serialization Package
//  ----------------------------------
//  ObjectBytesInputStream.java
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 2003 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//
//  Based on an idea submitted by Rickard Oberg.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any legal purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

package com.coyotegulch.jisp;

import java.io.*;

class ObjectBytesInputStream extends InputStream
{
    private byte[]  m_buffer;
    private int     m_index;
    private int     m_limit;
    private boolean m_closed;

    public ObjectBytesInputStream(byte[] data) throws IOException
    {
        this(data, 0, data.length);
    }

    public ObjectBytesInputStream(byte[] data, int offset, int length) throws IOException
    {
        super();
        
        if (data == null)
            throw new NullPointerException();
        else
        {
            if ((offset < 0) || (offset + length > data.length) || (length < 0))
                throw new IndexOutOfBoundsException();
            else
            {
                m_buffer = data;
                m_index = offset;
                m_limit = offset + length;
            }
        }
    }
    
    public int read() throws IOException
    {
        int result = -1;
        
        if (m_closed)
            throw new IOException("Stream closed");
        else
        {
            if (m_index < m_limit)
                result = m_buffer[m_index++] & 0xff;
        }
        
        return result;
    }

    public int read(byte data[], int offset, int length) throws IOException
    {
        int result = -1;
        
        if (data == null)
            throw new NullPointerException();
        else
        {
            if ((offset < 0) || (offset + length > data.length) || (length < 0))
                throw new IndexOutOfBoundsException();
            else
            {
                if (m_closed)
                    throw new IOException("Stream closed");
                else
                {
                    if (m_index < m_limit)
                    {
                        // restrict length to available data
                        if (length > m_limit - m_index)
                            length = m_limit - m_index;
                            
                        // copy out the subarray
                        System.arraycopy(m_buffer, m_index, data, offset, length);
                        m_index += length;
                        result = length;
                    }
                }
            }
        }
        
        return result;
    }

    public long skip(long amount) throws IOException
    {
        long result = 0;
        
        if (m_closed)
            throw new IOException("Stream closed");
        else
        {
            if (amount > 0)
            {
                // restrict amount to available data
                if (amount > m_limit - m_index)
                    amount = m_limit - m_index;
                    
                m_index += (int) amount;
                result = amount;
            }
        }
        
        return result;
    }

    public int available() throws IOException
    {
        if (m_closed)
           throw new IOException("Stream closed");
          
        return m_limit - m_index;
    }

    public void close()
    {
        m_closed = true;
    }

    public boolean markSupported()
    {
        return false;
    }
}
