//-----------------------------------------------------------------------
//	Java Indexed Serialization Package
//  ----------------------------------
//  Page.java
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 1996-2003 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any legal purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

package com.coyotegulch.jisp;

import java.io.*;

class Page extends BTreeShared implements Externalizable
{
    // serialization constant
    static final long serialVersionUID = -8324209659131142291L;
    
    // fields
    public PageHeader   m_header;
    public KeyObject [] m_key;    // array of key values
    public long []      m_recPtr; // record pointers
    public long []      m_link;   // links to other pages

    // constructors
    public Page()
    {
        m_header = null;
        m_key    = null;
        m_recPtr = null;
        m_link   = null;
    }

    public Page(PageFileHeader filehdr) throws BTreeException
    {
        // load header information
        m_header = new PageHeader();

        m_header.m_filePtr   = NULL_PTR;
        m_header.m_parentPtr = NULL_PTR;
        m_header.m_numKeys   = 0;

        // allocate arrays
        m_key =    new KeyObject [filehdr.m_maxKeys];
        m_recPtr = new long      [filehdr.m_maxKeys];
        m_link =   new long      [filehdr.m_order];

        // fill arrays with empty values
        for (int n = 0; n < filehdr.m_order; ++n)
            m_link[n] = NULL_PTR;
        
        for (int n = 0; n < filehdr.m_maxKeys; ++n)
        {
            m_recPtr[n] = NULL_PTR;
            m_key[n]    = filehdr.m_nullKey.makeNullKey();
        }
    }

    // serialization
    public void writeExternal(ObjectOutput out) throws IOException
    {
        // write order and key length
        out.writeObject(m_header);

        // write pointers and links
        out.writeObject(m_recPtr);
        out.writeObject(m_link);

        // write keys
        for (int n = 0; n < m_key.length; ++n)
            out.writeObject(m_key[n]);
    }

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException
    {
        // read back key information
        m_header = (PageHeader)in.readObject();
        
        // read link arrays
        m_recPtr = (long [])in.readObject();
        m_link =   (long [])in.readObject();

        // read keys
        m_key = new KeyObject [m_recPtr.length];
        
        for (int n = 0; n < m_key.length; ++n)
            m_key[n] = (KeyObject)in.readObject();
    }
}
